% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/crypto_history.R
\name{crypto_history}
\alias{crypto_history}
\title{Get historic crypto currency market data}
\usage{
crypto_history(
  coin_list = NULL,
  convert = "USD",
  limit = NULL,
  start_date = NULL,
  end_date = NULL,
  interval = NULL,
  sleep = NULL,
  finalWait = TRUE
)
}
\arguments{
\item{coin_list}{string if NULL retrieve all currently existing coins (\code{crypto_list()}),
or provide list of crypto currencies in the \code{crypto_list()} format (e.g. current and/or dead coins since 2015)}

\item{convert}{(default: USD) to one or more of available fiat or precious metals prices (\code{fiat_list()}). If more
than one are selected please separate by comma (e.g. "USD,BTC")}

\item{limit}{integer Return the top n records, default is all tokens}

\item{start_date}{string Start date to retrieve data from, format 'yyyymmdd'}

\item{end_date}{string End date to retrieve data from, format 'yyyymmdd', if not provided, today will be assumed}

\item{interval}{string Interval with which to sample data, default 'daily'. Must be one of \verb{"hourly" "daily" "weekly" "monthly" "yearly" "1d" "2d" "3d" "7d" "14d" "15d" "30d" "60d" "90d" "365d"}}

\item{sleep}{integer Seconds to sleep for between API requests}

\item{finalWait}{to avoid calling the web-api again with another command before 60s are over (TRUE=default)}
}
\value{
Crypto currency historic OHLC market data in a dataframe and additional information via attribute "info":
\item{timestamp}{Timestamp of entry in database}
\item{slug}{Coin url slug}
\item{id}{Coin market cap unique id}
\item{name}{Coin name}
\item{symbol}{Coin symbol}
\item{ref_cur}{Reference currency}
\item{open}{Market open}
\item{high}{Market high}
\item{low}{Market low}
\item{close}{Market close}
\item{volume}{Volume 24 hours}
\item{time_open}{Timestamp of open}
\item{time_close}{Timestamp of close}
\item{time_high}{Timestamp of high}
\item{time_low}{Timestamp of low}

This is the main function of the crypto package. If you want to retrieve
ALL active coins then do not pass an argument to \code{crypto_history()}, or pass the coin name.
}
\description{
Scrape the crypto currency historic market tables from
'CoinMarketCap' \url{https://coinmarketcap.com} and display
the results in a dataframe/tibble. This can be used to conduct
analysis on the crypto financial markets or to attempt
to predict future market movements or trends.
}
\examples{
\dontrun{

# Retrieving market history for ALL crypto currencies
all_coins <- crypto_history(limit = 2)
one_coin <- crypto_history(limit = 1)

# Retrieving market history since 2020 for ALL crypto currencies
all_coins <- crypto_history(start_date = '20200101',limit=10)

# Retrieve 2015 history for all 2015 crypto currencies
coin_list_2015 <- crypto_list(only_active=TRUE) \%>\%
              dplyr::filter(first_historical_data<="2015-12-31",
              last_historical_data>="2015-01-01")
coins_2015 <- crypto_history(coin_list = coin_list_2015,
start_date = "20150101", end_date="20151231", limit=20, interval="90d")

}

}
